==> huaweicloudsdkas-3.0.53-py2.py3-none-any.whl: huaweicloudsdkas/v1/model/list_hook_instances_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListHookInstancesRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'scaling_group_id': 'str',
        'instance_id': 'str'
    }

    attribute_map = {
        'scaling_group_id': 'scaling_group_id',
        'instance_id': 'instance_id'
    }

    def __init__(self, scaling_group_id=None, instance_id=None):
        """ListHookInstancesRequest - a model defined in huaweicloud sdk"""
        
        

        self._scaling_group_id = None
        self._instance_id = None
        self.discriminator = None

        self.scaling_group_id = scaling_group_id
        if instance_id is not None:
            self.instance_id = instance_id

    @property
    def scaling_group_id(self):
        """Gets the scaling_group_id of this ListHookInstancesRequest.

        伸缩组ID。

        :return: The scaling_group_id of this ListHookInstancesRequest.
        :rtype: str
        """
        return self._scaling_group_id

    @scaling_group_id.setter
    def scaling_group_id(self, scaling_group_id):
        """Sets the scaling_group_id of this ListHookInstancesRequest.

        伸缩组ID。

        :param scaling_group_id: The scaling_group_id of this ListHookInstancesRequest.
        :type: str
        """
        self._scaling_group_id = scaling_group_id

    @property
    def instance_id(self):
        """Gets the instance_id of this ListHookInstancesRequest.

        伸缩实例ID。

        :return: The instance_id of this ListHookInstancesRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this ListHookInstancesRequest.

        伸缩实例ID。

        :param instance_id: The instance_id of this ListHookInstancesRequest.
        :type: str
        """
        self._instance_id = instance_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListHookInstancesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkas-3.0.64-py2.py3-none-any.whl: huaweicloudsdkas/v1/model/list_hook_instances_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListHookInstancesRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'scaling_group_id': 'str',
        'instance_id': 'str'
    }

    attribute_map = {
        'scaling_group_id': 'scaling_group_id',
        'instance_id': 'instance_id'
    }

    def __init__(self, scaling_group_id=None, instance_id=None):
        """ListHookInstancesRequest - a model defined in huaweicloud sdk"""
        
        

        self._scaling_group_id = None
        self._instance_id = None
        self.discriminator = None

        self.scaling_group_id = scaling_group_id
        if instance_id is not None:
            self.instance_id = instance_id

    @property
    def scaling_group_id(self):
        """Gets the scaling_group_id of this ListHookInstancesRequest.

        伸缩组ID。

        :return: The scaling_group_id of this ListHookInstancesRequest.
        :rtype: str
        """
        return self._scaling_group_id

    @scaling_group_id.setter
    def scaling_group_id(self, scaling_group_id):
        """Sets the scaling_group_id of this ListHookInstancesRequest.

        伸缩组ID。

        :param scaling_group_id: The scaling_group_id of this ListHookInstancesRequest.
        :type: str
        """
        self._scaling_group_id = scaling_group_id

    @property
    def instance_id(self):
        """Gets the instance_id of this ListHookInstancesRequest.

        伸缩实例ID。

        :return: The instance_id of this ListHookInstancesRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this ListHookInstancesRequest.

        伸缩实例ID。

        :param instance_id: The instance_id of this ListHookInstancesRequest.
        :type: str
        """
        self._instance_id = instance_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListHookInstancesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
